/*---------------------------------------------------------------------------------------------------------------------------------------------------
 * main.c - demo main module to test irmp decoder
 *
 * Copyright (c) 2009-2012 Frank Meyer - frank(at)fli4l.de
 *
 * $Id: main.c,v 1.14 2012/05/15 10:25:21 fm Exp $
 *
 * ATMEGA88 @ 8 MHz
 *
 * Fuses: lfuse: 0xE2 hfuse: 0xDC efuse: 0xF9
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *---------------------------------------------------------------------------------------------------------------------------------------------------
 */
#ifndef F_CPU
#define F_CPU 12000000UL // or whatever may be your frequency
#warning "F_CPU ist 12000000"
#endif
#include <avr/io.h>
#include <avr/wdt.h>

#include "irmp.h"
#include "usbdrv.h"
#include "infrahid.h"



#ifndef F_CPU
#error F_CPU unkown
#endif

//volatile uint16_t rep_send_cnt = 0;

void
timer1_init (void)
{
#if defined (__AVR_ATtiny45__) || defined (__AVR_ATtiny85__)                // ATtiny45 / ATtiny85:

#if F_CPU >= 16000000L
    OCR1C   =  (F_CPU / F_INTERRUPTS / 8) - 1;                              // compare value: 1/15000 of CPU frequency, presc = 8
    TCCR1   = (1 << CTC1) | (1 << CS12);                                    // switch CTC Mode on, set prescaler to 8
#else
    OCR1C   =  (F_CPU / F_INTERRUPTS / 4) - 1;                              // compare value: 1/15000 of CPU frequency, presc = 4
    TCCR1   = (1 << CTC1) | (1 << CS11) | (1 << CS10);                      // switch CTC Mode on, set prescaler to 4
#endif

#else                                                                       // ATmegaXX:
    OCR1A   =  (F_CPU / F_INTERRUPTS) - 1;                                  // compare value: 1/15000 of CPU frequency
    TCCR1B  = (1 << WGM12) | (1 << CS10);                                   // switch CTC Mode on, set prescaler to 1
#endif

#ifdef TIMSK1
    TIMSK1  = 1 << OCIE1A;                                                  // OCIE1A: Interrupt by timer compare
#else
    TIMSK   = 1 << OCIE1A;                                                  // OCIE1A: Interrupt by timer compare
#endif
}

/*---------------------------------------------------------------------------------------------------------------------------------------------------
 * Timer 1 output compare A interrupt service routine, called every 1/15000 sec
 *---------------------------------------------------------------------------------------------------------------------------------------------------
 */
#ifdef TIM1_COMPA_vect                                                      // ATtiny84
ISR(TIM1_COMPA_vect)
#else
ISR(TIMER1_COMPA_vect)
#endif
{
  (void) irmp_ISR();                                                        // call irmp ISR
  // call other timer interrupt routines...
 // if(rep_send_cnt>0){
//	    rep_send_cnt++;
 // }
}


int main (void)
{
	wdt_enable(WDTO_1S);
	PORTB |= (1 << PB0); //LED Ausgang fr infrahid
	PORTD = 0xfa;   /* 1111 1010 bin: activate pull-ups except on USB lines */
	DDRD  = 0x05;   /* 0000 0101 bin: all pins input except USB (-> USB reset) */
	TCCR0 = 5;		/* prescaler = 1/1024 -> overflow at 21.8 ms */
	
    IRMP_DATA irmp_data;
	//IRMP_DATA irmp_data_send;

	//extern unsigned long ir_data; //wird in "infrahid.c" deklariert

    irmp_init();                                                            // initialize irmp
    timer1_init();                                                          // initialize timer 1
	usbReset();
	usbInit();
    sei ();                                                                 // enable interrupts

	
    for (;;)
    {
		wdt_reset();
		usbPoll();
		
		
		//ir_data=0x20DF;
// 		irmp_data.protocol=0x02;
// 		irmp_data.command=0x57;

		
		
		if (irmp_get_data (&irmp_data))
		{
			ir_input(&irmp_data);
		}
		
		
       /* if (irmp_get_data (&irmp_data))
        {
			irmp_uart_putc('P');
			irmp_uart_putc(':');
			irmp_uart_putc(irmp_data.protocol);
			irmp_uart_putc(' ');
			irmp_uart_putc('A');
			irmp_uart_putc(':');
			irmp_uart_putc(irmp_data.address);
			irmp_uart_putc(' ');
			irmp_uart_putc('C');
			irmp_uart_putc(':');
			irmp_uart_putc(irmp_data.command);
			irmp_uart_putc(' ');
			irmp_uart_putc('F');
			irmp_uart_putc(':');
			irmp_uart_putc(irmp_data.flags);
			irmp_uart_putc('\r');
			irmp_uart_putc('\n');*/
			
            // ir signal decoded, do something here...
            // irmp_data.protocol is the protocol, see irmp.h
            // irmp_data.address is the address/manufacturer code of ir sender
            // irmp_data.command is the command code
            // irmp_protocol_names[irmp_data.protocol] is the protocol name (if enabled, see irmpconfig.h)
			//}
		if (TIFR & _BV(TOV0)) {
			TIFR = _BV(TOV0);
			idle_timer();
		}		
			
		send_packets();
        
    }
}
